function varargout = MSLAB_LOAD(varargin)

if nargin == 0  % LAUNCH GUI

	fig = openfig(mfilename,'reuse');

	% Use system color scheme for figure:
	set(fig,'Color',get(0,'defaultUicontrolBackgroundColor'));

	% Generate a structure of handles to pass to callbacks, and store it. 
	handles = guihandles(fig);
	guidata(fig, handles);

	if nargout > 0
		varargout{1} = fig;
	end

elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK

	try
		if (nargout)
			[varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
		else
			feval(varargin{:}); % FEVAL switchyard
		end
	catch
		disp(lasterr);
	end

end


%| ABOUT CALLBACKS:
%| GUIDE automatically appends subfunction prototypes to this file, and 
%| sets objects' callback properties to call them through the FEVAL 
%| switchyard above. This comment describes that mechanism.
%|
%| Each callback subfunction declaration has the following form:
%| <SUBFUNCTION_NAME>(H, EVENTDATA, HANDLES, VARARGIN)
%|
%| The subfunction name is composed using the object's Tag and the 
%| callback type separated by '_', e.g. 'slider2_Callback',
%| 'figure1_CloseRequestFcn', 'axis1_ButtondownFcn'.
%|
%| H is the callback object's handle (obtained using GCBO).
%|
%| EVENTDATA is empty, but reserved for future use.
%|
%| HANDLES is a structure containing handles of components in GUI using
%| tags as fieldnames, e.g. handles.figure1, handles.slider2. This
%| structure is created at GUI startup using GUIHANDLES and stored in
%| the figure's application data using GUIDATA. A copy of the structure
%| is passed to each callback.  You can store additional information in
%| this structure at GUI startup, and you can change the structure
%| during callbacks.  Call guidata(h, handles) after changing your
%| copy to replace the stored original so that subsequent callbacks see
%| the updates. Type "help guihandles" and "help guidata" for more
%| information.
%|
%| VARARGIN contains any extra arguments you have passed to the
%| callback. Specify the extra arguments by editing the callback
%| property in the inspector. By default, GUIDE sets the property to:
%| <MFILENAME>('<SUBFUNCTION_NAME>', gcbo, [], guidata(gcbo))
%| Add any extra arguments after the last argument, before the final
%| closing parenthesis.



% --------------------------------------------------------------------
function varargout = edit1_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
a= str2double(get(handles.edit1,'String'));
if isnan(a) | a<=0
   errordlg('You must enter a positive numeric value for slab length','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit2_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
b= str2double(get(handles.edit2,'String'));
if isnan(b) | b<=0
   errordlg('You must enter a positive numeric value for slab width','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit3_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
h= str2double(get(handles.edit3,'String'));
if isnan(h) | h<=0
   errordlg('You must enter a positive numeric value for slab thickness','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit4_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');

E= str2double(get(handles.edit4,'String'));
if isnan(E) | E<=0
   errordlg('You must enter a positive numeric value for slab elastic modulus','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit5_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
mu= str2double(get(handles.edit5,'String'));
if isnan(mu) | mu<=0
   errordlg('You must enter a positive numeric value for slab Poisson ratio','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit6_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
k= str2double(get(handles.edit6,'String'));
if isnan(k) | k<=0
   errordlg('You must enter a positive numeric value for modulus of subgrade reaction','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit7_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------
function varargout = edit8_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');



% --------------------------------------------------------------------
function varargout = edit9_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
x0= str2double(get(handles.edit9,'String'));
if isnan(x0)
   errordlg('You must enter a numeric value for x coordinate of load center ','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit10_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
y0= str2double(get(handles.edit10,'String'));
if isnan(y0)
   errordlg('You must enter a numeric value for y coordinate of load center ','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit11_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
q0= str2double(get(handles.edit11,'String'));
if isnan(q0)
   errordlg('You must enter a numeric value for load pressure ','Bad Input','modal')
end


% --------------------------------------------------------------------
function varargout = edit12_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
cc= str2double(get(handles.edit12,'String'));
if isnan(cc) | cc<=0
   errordlg('You must enter a positive numeric value for length of load area ','Bad Input','modal')
end


% --------------------------------------------------------------------
function varargout = edit13_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');

dd= str2double(get(handles.edit13,'String'));
if isnan(dd) | dd<=0
   errordlg('You must enter a positive numeric value for width of load area ','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit14_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');

x= str2double(get(handles.edit14,'String'));
if isnan(x)
   errordlg('You must enter a numeric value for x coordinate of computation point ','Bad Input','modal')
end
% --------------------------------------------------------------------
function varargout = edit15_Callback(h, eventdata, handles, varargin)


set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
y= str2double(get(handles.edit15,'String'));
if isnan(y)
   errordlg('You must enter a numeric value for y coordinate of computation point ','Bad Input','modal')
end
% --------------------------------------------------------------------
function varargout = edit16_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------
function varargout = edit17_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
Rwx= str2double(get(handles.edit17,'String'));
if isnan(Rwx) | Rwx<0 | Rwx>1
   errordlg('You must enter a nonnegtive numeric value between 0 and 1 for joint load transfer efficiency in x direction ','Bad Input','modal')
end

% --------------------------------------------------------------------
function varargout = edit18_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
Rwy= str2double(get(handles.edit18,'String'));
if isnan(Rwy) | Rwy<0 | Rwy>1
   errordlg('You must enter a nonnegtive numeric value between 0 and 1 for joint load transfer efficiency in y direction ','Bad Input','modal')
end



% --------------------------------------------------------------------
function varargout = edit19_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');



% --------------------------------------------------------------------
function varargout = edit20_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');



% --------------------------------------------------------------------
function varargout = edit21_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------
function varargout = edit22_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------
function varargout = edit23_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------
function varargout = edit24_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');



% --------------------------------------------------------------------
function varargout = edit25_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');

% --------------------------------------------------------------------
function varargout = edit26_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------
function varargout = edit27_Callback(h, eventdata, handles, varargin)

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------
function varargout = edit28_Callback(h, eventdata, handles, varargin)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
% --------------------------------------------------------------------

function mutual_exclude(off)
set(off,'Value',0)

% --------------------------------------------------------------------
function varargout = radiobutton1_Callback(h, eventdata, handles, varargin)

off = handles.radiobutton2;
mutual_exclude(off)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');

% --------------------------------------------------------------------
function varargout = radiobutton2_Callback(h, eventdata, handles, varargin)

off =handles.radiobutton1;
mutual_exclude(off)
set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');


% --------------------------------------------------------------------


% --------------------------------------------------------------------
function varargout = pushbutton1_Callback(h, eventdata, handles, varargin)
r1=get(handles.radiobutton1,'Value');
r2=get(handles.radiobutton2,'Value');
if isequal(r1,0) & isequal(r2,0) 
   errordlg('You must choose a multiple-slab model','Bad Input','modal')
end
a= str2double(get(handles.edit1,'String'));

b= str2double(get(handles.edit2,'String'));

h= str2double(get(handles.edit3,'String'));

E= str2double(get(handles.edit4,'String'));

mu= str2double(get(handles.edit5,'String'));

k= str2double(get(handles.edit6,'String'));

Rwx= str2double(get(handles.edit17,'String'));

Rwy= str2double(get(handles.edit18,'String'));

x0= str2double(get(handles.edit9,'String'));

y0= str2double(get(handles.edit10,'String'));

q0= str2double(get(handles.edit11,'String'));

cc= str2double(get(handles.edit12,'String'));

dd= str2double(get(handles.edit13,'String'));

x= str2double(get(handles.edit14,'String'));

y= str2double(get(handles.edit15,'String'));

m=10;

n=10;

set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
if isnan(a) | a<=0
   errordlg('You must enter a positive numeric value for slab length','Bad Input','modal')
end
if isnan(b) | b<=0
   errordlg('You must enter a positive numeric value for slab width','Bad Input','modal')
end
if isnan(h) | h<=0
   errordlg('You must enter a positive numeric value for slab thickness','Bad Input','modal')
end
if isnan(E) | E<=0
   errordlg('You must enter a positive numeric value for slab elastic modulus','Bad Input','modal')
end
if isnan(mu) | mu<=0
   errordlg('You must enter a positive numeric value for slab Poisson ratio','Bad Input','modal')
end
if isnan(k) | k<=0
   errordlg('You must enter a positive numeric value for modulus of subgrade reaction','Bad Input','modal')
end
if isnan(x0)
   errordlg('You must enter a numeric value for x coordinate of load center ','Bad Input','modal')
end
if isnan(y0)
   errordlg('You must enter a numeric value for y coordinate of load center ','Bad Input','modal')
end
if isnan(q0)
   errordlg('You must enter a numeric value for load pressure ','Bad Input','modal')
end
if isnan(cc) | cc<=0
   errordlg('You must enter a positive numeric value for length of load area ','Bad Input','modal')
end
if isnan(dd) | dd<=0
   errordlg('You must enter a positive numeric value for width of load area ','Bad Input','modal')
end
if isnan(x)
   errordlg('You must enter a numeric value for x coordinate of computation point ','Bad Input','modal')
end
if isnan(y)
   errordlg('You must enter a numeric value for y coordinate of computation point ','Bad Input','modal')
end
if isnan(Rwx) | Rwx<0 | Rwx>1
   errordlg('You must enter a nonnegtive numeric value between 0 and 1 for joint load transfer efficiency in x direction ','Bad Input','modal')
end
if isnan(Rwy) | Rwy<0 | Rwy>1
   errordlg('You must enter a nonnegtive numeric value between 0 and 1 for joint load transfer efficiency in y direction ','Bad Input','modal')
end

pause(2);


if r1>0
      set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');

    [W, SX, SY]=nineslabload(a,b,h,E,mu,k,Rwx,Rwy,x0,y0,q0,cc,dd,x,y,m,n);
    
set(handles.edit19,'String',num2str(W));

set(handles.edit20,'String',num2str(SX));

set(handles.edit21,'String',num2str(SY));

end
if r2>0
    set(handles.edit19,'String',' ');

set(handles.edit20,'String',' ');

set(handles.edit21,'String',' ');
    [W, SX, SY]=sixslabload(a,b,h,E,mu,k,Rwx,Rwy,x0,y0,q0,cc,dd,x,y,m,n);
    set(handles.edit19,'String',num2str(W));

  set(handles.edit20,'String',num2str(SX));

set(handles.edit21,'String',num2str(SY));

end



function edit29_Callback(hObject, eventdata, handles)
% hObject    handle to edit29 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit29 as text
%        str2double(get(hObject,'String')) returns contents of edit29 as a double


% --- Executes during object creation, after setting all properties.
function edit29_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit29 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


